@@ -23,9 +23,6 @@ import oslo_messaging
 import six
 from stevedore import extension
 
-from ceilometer.i18n import _LE
-from ceilometer import messaging
-
 LOG = log.getLogger(__name__)
 
 ExchangeTopics = collections.namedtuple('ExchangeTopics',
@@ -113,11 +110,9 @@ class NotificationBase(PluginBase):
     def _process_notifications(self, priority, notifications):
         for notification in notifications:
             try:
-                notification = messaging.convert_to_old_notification_format(
-                    priority, notification)
                 self.to_samples_and_publish(notification)
             except Exception:
-                LOG.error(_LE('Fail to process notification'), exc_info=True)
+                LOG.error('Fail to process notification', exc_info=True)
 
     def to_samples_and_publish(self, notification):
         """Return samples produced by *process_notification*.
@@ -262,7 +257,7 @@ class DiscoveryBase(object):
     def group_id(self):
         """Return group id of this discovery.
 
-        All running recoveries with the same group_id should return the same
+        All running discoveries with the same group_id should return the same
         set of resources at a given point in time. By default, a discovery is
         put into a global group, meaning that all discoveries of its type
         running anywhere in the cloud, return the same set of resources.
