@@ -16,6 +16,7 @@
 import hashlib
 from lxml import etree
 import operator
+import threading
 
 import cachetools
 from novaclient import exceptions
@@ -107,23 +108,17 @@ class InstanceDiscovery(plugin_base.DiscoveryBase):
         self.expiration_time = conf.compute.resource_update_interval
         self.cache_expiry = conf.compute.resource_cache_expiry
         if self.method == "libvirt_metadata":
-            self._connection = None
             # 4096 instances on a compute should be enough :)
             self._flavor_cache = cachetools.LRUCache(4096)
         else:
+            self.lock = threading.Lock()
             self.instances = {}
             self.last_run = None
             self.last_cache_expire = None
 
     @property
     def connection(self):
-        if not self._connection:
-            self._connection = libvirt_utils.get_libvirt_connection(self.conf)
-        return self._connection
-
-    @connection.setter
-    def connection(self, value):
-        self._connection = value
+        return libvirt_utils.refresh_libvirt_connection(self.conf, self)
 
     def discover(self, manager, param=None):
         """Discover resources to monitor."""
@@ -166,55 +161,42 @@ class InstanceDiscovery(plugin_base.DiscoveryBase):
             # flavor. this is why nova doesn't put the id in the libvirt
             # metadata
 
-            try:
-                flavor_xml = metadata_xml.find(
-                    "./flavor")
-                user_id = metadata_xml.find(
-                    "./owner/user").attrib["uuid"]
-                project_id = metadata_xml.find(
-                    "./owner/project").attrib["uuid"]
-                instance_name = metadata_xml.find(
-                    "./name").text
-                instance_arch = os_type_xml.attrib["arch"]
-
-                flavor = {
-                    "id": self.get_flavor_id(flavor_xml.attrib["name"]),
-                    "name": flavor_xml.attrib["name"],
-                    "vcpus": self._safe_find_int(flavor_xml, "vcpus"),
-                    "ram": self._safe_find_int(flavor_xml, "memory"),
-                    "disk": self._safe_find_int(flavor_xml, "disk"),
-                    "ephemeral": self._safe_find_int(flavor_xml, "ephemeral"),
-                    "swap": self._safe_find_int(flavor_xml, "swap"),
-                }
-
-                # The image description is partial, but Gnocchi only care about
-                # the id, so we are fine
-                image_xml = metadata_xml.find("./root[@type='image']")
-                image = ({'id': image_xml.attrib['uuid']}
-                         if image_xml is not None else None)
-            except AttributeError:
-                LOG.error(
-                    "Fail to get domain uuid %s metadata: "
-                    "metadata was missing expected attributes",
-                    domain.UUIDString())
-                continue
-
+            # This implements
+            flavor_xml = metadata_xml.find("./flavor")
+            flavor = {
+                "id": self.get_flavor_id(flavor_xml.attrib["name"]),
+                "name": flavor_xml.attrib["name"],
+                "vcpus": self._safe_find_int(flavor_xml, "vcpus"),
+                "ram": self._safe_find_int(flavor_xml, "memory"),
+                "disk": self._safe_find_int(flavor_xml, "disk"),
+                "ephemeral": self._safe_find_int(flavor_xml, "ephemeral"),
+                "swap": self._safe_find_int(flavor_xml, "swap"),
+            }
             dom_state = domain.state()[0]
             vm_state = libvirt_utils.LIBVIRT_POWER_STATE.get(dom_state)
             status = libvirt_utils.LIBVIRT_STATUS.get(dom_state)
 
+            user_id = metadata_xml.find("./owner/user").attrib["uuid"]
+            project_id = metadata_xml.find("./owner/project").attrib["uuid"]
+
             # From:
             # https://github.com/openstack/nova/blob/852f40fd0c6e9d8878212ff3120556668023f1c4/nova/api/openstack/compute/views/servers.py#L214-L220
             host_id = hashlib.sha224(
                 (project_id + self.conf.host).encode('utf-8')).hexdigest()
 
+            # The image description is partial, but Gnocchi only care about the
+            # id, so we are fine
+            image_xml = metadata_xml.find("./root[@type='image']")
+            image = ({'id': image_xml.attrib['uuid']}
+                     if image_xml is not None else None)
+
             instance_data = {
                 "id": domain.UUIDString(),
-                "name": instance_name,
+                "name": metadata_xml.find("./name").text,
                 "flavor": flavor,
                 "image": image,
                 "os_type": os_type_xml.text,
-                "architecture": instance_arch,
+                "architecture": os_type_xml.attrib["arch"],
 
                 "OS-EXT-SRV-ATTR:instance_name": domain.name(),
                 "OS-EXT-SRV-ATTR:host": self.conf.host,
@@ -228,7 +210,7 @@ class InstanceDiscovery(plugin_base.DiscoveryBase):
 
                 # NOTE(sileht): Other fields that Ceilometer tracks
                 # where we can't get the value here, but their are
-                # retreived by notification
+                # retrieved by notification
                 "metadata": {},
                 # "OS-EXT-STS:task_state"
                 # 'reservation_id',
@@ -256,35 +238,35 @@ class InstanceDiscovery(plugin_base.DiscoveryBase):
         instances = []
         # NOTE(ityaptin) we update make a nova request only if
         # it's a first discovery or resources expired
-        if not self.last_run or secs_from_last_update >= self.expiration_time:
-            try:
-                if secs_from_last_expire < self.cache_expiry and self.last_run:
-                    since = self.last_run.isoformat()
-                else:
-                    since = None
-                    self.instances.clear()
-                    self.last_cache_expire = utc_now
-                instances = self.nova_cli.instance_get_all_by_host(
-                    self.conf.host, since)
-                self.last_run = utc_now
-            except Exception:
-                # NOTE(zqfan): instance_get_all_by_host is wrapped and will log
-                # exception when there is any error. It is no need to raise it
-                # again and print one more time.
-                return []
+        with self.lock:
+            if (not self.last_run or secs_from_last_update >=
+                    self.expiration_time):
+                try:
+                    if (secs_from_last_expire < self.cache_expiry and
+                            self.last_run):
+                        since = self.last_run.isoformat()
+                    else:
+                        since = None
+                        self.instances.clear()
+                        self.last_cache_expire = utc_now
+                    instances = self.nova_cli.instance_get_all_by_host(
+                        self.conf.host, since)
+                    self.last_run = utc_now
+                except Exception:
+                    # NOTE(zqfan): instance_get_all_by_host is wrapped and will
+                    # log exception when there is any error. It is no need to
+                    #  raise it again and print one more time.
+                    return []
 
-        for instance in instances:
-            if getattr(instance, 'OS-EXT-STS:vm_state', None) in ['deleted',
-                                                                  'error']:
-                self.instances.pop(instance.id, None)
-            else:
-                self.instances[instance.id] = instance
+            for instance in instances:
+                if getattr(instance, 'OS-EXT-STS:vm_state', None) in [
+                   'deleted', 'error']:
+                    self.instances.pop(instance.id, None)
+                else:
+                    self.instances[instance.id] = instance
 
         return self.instances.values()
 
     @property
     def group_id(self):
-        if self.method == "workload_partitioning":
-            return self.conf.host
-        else:
-            return None
+        return self.conf.host
