@@ -26,12 +26,10 @@ import ceilometer.compute.virt.inspector
 import ceilometer.compute.virt.libvirt.utils
 import ceilometer.compute.virt.vmware.inspector
 import ceilometer.compute.virt.xenapi.inspector
-import ceilometer.coordination
 import ceilometer.dispatcher
 import ceilometer.dispatcher.file
 import ceilometer.dispatcher.gnocchi_opts
 import ceilometer.dispatcher.http
-import ceilometer.energy.kwapi
 import ceilometer.event.converter
 import ceilometer.exchange_control
 import ceilometer.hardware.discovery
@@ -58,16 +56,22 @@ import ceilometer.volume.discovery
 
 
 OPTS = [
-    cfg.StrOpt('host',
-               default=socket.gethostname(),
-               sample_default='<your_hostname>',
-               help='Name of this node, which must be valid in an AMQP '
-               'key. Can be an opaque identifier. For ZeroMQ only, must '
-               'be a valid host name, FQDN, or IP address.'),
+    cfg.HostAddressOpt('host',
+                       default=socket.gethostname(),
+                       sample_default='<your_hostname>',
+                       help='Name of this node, which must be valid in an '
+                       'AMQP key. Can be an opaque identifier. For ZeroMQ '
+                       'only, must be a valid host name, FQDN, or IP '
+                       'address.'),
     cfg.IntOpt('http_timeout',
                default=600,
                help='Timeout seconds for HTTP requests. Set it to None to '
                     'disable timeout.'),
+    cfg.IntOpt('max_parallel_requests',
+               default=64,
+               min=1,
+               help='Maximum number of parallel requests for '
+               'services to handle at the same time.'),
 ]
 
 
@@ -82,7 +86,6 @@ def list_opts():
                          ceilometer.compute.virt.libvirt.utils.OPTS,
                          ceilometer.dispatcher.OPTS,
                          ceilometer.ipmi.notifications.ironic.OPTS,
-                         ceilometer.middleware.OPTS,
                          ceilometer.nova_client.OPTS,
                          ceilometer.objectstore.swift.OPTS,
                          ceilometer.pipeline.OPTS,
@@ -94,7 +97,20 @@ def list_opts():
                                 ceilometer.api.controllers.v2.root.API_OPTS)),
         ('collector', ceilometer.collector.OPTS),
         ('compute', ceilometer.compute.discovery.OPTS),
-        ('coordination', ceilometer.coordination.OPTS),
+        ('coordination', [
+            cfg.StrOpt(
+                'backend_url',
+                help='The backend URL to use for distributed coordination. If '
+                'left empty, per-deployment central agent and per-host '
+                'compute agent won\'t do workload '
+                'partitioning and will only function correctly if a '
+                'single instance of that service is running.'),
+            cfg.FloatOpt(
+                'check_watchers',
+                default=10.0,
+                help='Number of seconds between checks to see if group '
+                'membership has changed'),
+        ]),
         ('database', ceilometer.storage.OPTS),
         ('dispatcher_file', ceilometer.dispatcher.file.OPTS),
         ('dispatcher_http', ceilometer.dispatcher.http.http_dispatcher_opts),
@@ -108,20 +124,20 @@ def list_opts():
          itertools.chain(ceilometer.ipmi.platform.intel_node_manager.OPTS,
                          ceilometer.ipmi.pollsters.OPTS)),
         ('meter', ceilometer.meter.notifications.OPTS),
-        ('notification', ceilometer.notification.OPTS),
+        ('notification',
+         itertools.chain(ceilometer.notification.OPTS,
+                         ceilometer.notification.EXCHANGES_OPTS)),
         ('polling', ceilometer.agent.manager.POLLING_OPTS),
         ('publisher', ceilometer.publisher.utils.OPTS),
         ('publisher_notifier', ceilometer.publisher.messaging.NOTIFIER_OPTS),
         ('rgw_admin_credentials', ceilometer.objectstore.rgw.CREDENTIAL_OPTS),
         ('service_types',
-         itertools.chain(ceilometer.energy.kwapi.SERVICE_OPTS,
-                         ceilometer.image.discovery.SERVICE_OPTS,
+         itertools.chain(ceilometer.image.discovery.SERVICE_OPTS,
                          ceilometer.neutron_client.SERVICE_OPTS,
                          ceilometer.nova_client.SERVICE_OPTS,
                          ceilometer.objectstore.rgw.SERVICE_OPTS,
                          ceilometer.objectstore.swift.SERVICE_OPTS,
                          ceilometer.volume.discovery.SERVICE_OPTS,)),
-        ('storage', ceilometer.dispatcher.STORAGE_OPTS),
         ('vmware', ceilometer.compute.virt.vmware.inspector.OPTS),
         ('xenapi', ceilometer.compute.virt.xenapi.inspector.OPTS),
     ]
