@@ -28,15 +28,6 @@ CONF = config.CONF
 
 LOG = logging.getLogger(__name__)
 
-# Loop for up to 120 seconds waiting on notifications
-# NOTE(chdent): The choice of 120 seconds is fairly
-# arbitrary: Long enough to give the notifications the
-# chance to travel across a highly latent bus but not
-# so long as to allow excessive latency to never be visible.
-# TODO(chdent): Ideally this value would come from configuration.
-NOTIFICATIONS_WAIT = 120
-NOTIFICATIONS_SLEEP = 1
-
 
 class ClientManager(client.Manager):
 
@@ -62,6 +53,11 @@ class TestObjectStorageTelemetry(test.BaseTestCase):
     @classmethod
     def skip_checks(cls):
         super(TestObjectStorageTelemetry, cls).skip_checks()
+        if ("gnocchi" in CONF.service_available and
+                CONF.service_available.gnocchi):
+            skip_msg = ("%s skipped as gnocchi is enabled" %
+                        cls.__name__)
+            raise cls.skipException(skip_msg)
         if not CONF.service_available.swift:
             skip_msg = ("%s skipped as swift is not available" %
                         cls.__name__)
@@ -117,10 +113,10 @@ class TestObjectStorageTelemetry(test.BaseTestCase):
 
         self.assertTrue(
             test_utils.call_until_true(_check_samples,
-                                       NOTIFICATIONS_WAIT,
-                                       NOTIFICATIONS_SLEEP),
+                                       CONF.telemetry.notification_wait,
+                                       CONF.telemetry.notification_sleep),
             'Correct notifications were not received after '
-            '%s seconds.' % NOTIFICATIONS_WAIT)
+            '%s seconds.' % CONF.telemetry.notification_wait)
 
     def create_container(self):
         name = data_utils.rand_name('swift-scenario-container')
