@@ -14,11 +14,10 @@
 # under the License.
 """Tests for Ceilometer notify daemon."""
 
+import fixtures
 import mock
-from oslo_config import fixture as fixture_config
 import oslo_messaging
 from oslo_utils import fileutils
-from oslotest import mockpatch
 import six
 import yaml
 
@@ -26,6 +25,7 @@ from ceilometer.event import endpoint as event_endpoint
 from ceilometer import pipeline
 from ceilometer import publisher
 from ceilometer.publisher import test
+from ceilometer import service
 from ceilometer.tests import base as tests_base
 
 
@@ -123,15 +123,15 @@ class TestEventEndpoint(tests_base.BaseTestCase):
 
     def setUp(self):
         super(TestEventEndpoint, self).setUp()
-        self.CONF = self.useFixture(fixture_config.Config()).conf
-        self.CONF([])
+        self.CONF = service.prepare_service([], [])
         self.CONF.set_override("connection", "log://", group='database')
         self.setup_messaging(self.CONF)
 
-        self.useFixture(mockpatch.PatchObject(publisher, 'get_publisher',
-                                              side_effect=self.get_publisher))
+        self.useFixture(fixtures.MockPatchObject(
+            publisher, 'get_publisher',
+            side_effect=self.get_publisher))
         self.fake_publisher = mock.Mock()
-        self.useFixture(mockpatch.Patch(
+        self.useFixture(fixtures.MockPatch(
             'ceilometer.publisher.test.TestPublisher',
             return_value=self.fake_publisher))
 
