@@ -17,7 +17,6 @@
 
 import datetime
 import mock
-from oslo_config import fixture as fixture_config
 from oslotest import base
 import requests
 from six.moves.urllib import parse as urlparse
@@ -26,6 +25,7 @@ import uuid
 from ceilometer.event.storage import models as event
 from ceilometer.publisher import http
 from ceilometer import sample
+from ceilometer import service
 
 
 class TestHttpPublisher(base.BaseTestCase):
@@ -75,7 +75,7 @@ class TestHttpPublisher(base.BaseTestCase):
 
     def setUp(self):
         super(TestHttpPublisher, self).setUp()
-        self.CONF = self.useFixture(fixture_config.Config()).conf
+        self.CONF = service.prepare_service([], [])
 
     def test_http_publisher_config(self):
         """Test publisher config parameters."""
@@ -232,6 +232,27 @@ class TestHttpPublisher(base.BaseTestCase):
             publisher.publish_samples(self.sample_data)
             self.assertEqual('/path/to/cert.crt', post.call_args[1]['verify'])
 
+    def test_post_basic_auth(self):
+        parsed_url = urlparse.urlparse(
+            'http://alice:l00kingGla$$@localhost:90/path1?')
+        publisher = http.HttpPublisher(self.CONF, parsed_url)
+
+        with mock.patch.object(requests.Session, 'post') as post:
+            publisher.publish_samples(self.sample_data)
+            self.assertEqual(('alice', 'l00kingGla$$'),
+                             post.call_args[1]['auth'])
+
+    def test_post_client_cert_auth(self):
+        parsed_url = urlparse.urlparse('http://localhost:90/path1?'
+                                       'clientcert=/path/to/cert.crt&'
+                                       'clientkey=/path/to/cert.key')
+        publisher = http.HttpPublisher(self.CONF, parsed_url)
+
+        with mock.patch.object(requests.Session, 'post') as post:
+            publisher.publish_samples(self.sample_data)
+            self.assertEqual(('/path/to/cert.crt', '/path/to/cert.key'),
+                             post.call_args[1]['cert'])
+
     def test_post_raw_only(self):
         parsed_url = urlparse.urlparse('http://localhost:90/path1?raw_only=1')
         publisher = http.HttpPublisher(self.CONF, parsed_url)
