@@ -18,13 +18,13 @@ import datetime
 import uuid
 
 import mock
-from oslo_config import fixture as fixture_config
 from oslo_utils import netutils
 
 from ceilometer.event.storage import models as event
 from ceilometer.publisher import kafka_broker as kafka
 from ceilometer.publisher import messaging as msg_publisher
 from ceilometer import sample
+from ceilometer import service
 from ceilometer.tests import base as tests_base
 
 
@@ -98,7 +98,7 @@ class TestKafkaPublisher(tests_base.BaseTestCase):
 
     def setUp(self):
         super(TestKafkaPublisher, self).setUp()
-        self.CONF = self.useFixture(fixture_config.Config()).conf
+        self.CONF = service.prepare_service([], [])
 
     def test_publish(self):
         publisher = kafka.KafkaBrokerPublisher(self.CONF, netutils.urlsplit(
