@@ -12,12 +12,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import fixtures
 import glanceclient
 import mock
 import novaclient
-from oslo_config import fixture as fixture_config
 from oslotest import base
-from oslotest import mockpatch
 
 from ceilometer import nova_client
 from ceilometer import service
@@ -27,15 +26,14 @@ class TestNovaClient(base.BaseTestCase):
 
     def setUp(self):
         super(TestNovaClient, self).setUp()
-        conf = service.prepare_service([], [])
-        self.CONF = self.useFixture(fixture_config.Config(conf)).conf
+        self.CONF = service.prepare_service([], [])
         self._flavors_count = 0
         self._images_count = 0
         self.nv = nova_client.Client(self.CONF)
-        self.useFixture(mockpatch.PatchObject(
+        self.useFixture(fixtures.MockPatchObject(
             self.nv.nova_client.flavors, 'get',
             side_effect=self.fake_flavors_get))
-        self.useFixture(mockpatch.PatchObject(
+        self.useFixture(fixtures.MockPatchObject(
             self.nv.glance_client.images, 'get',
             side_effect=self.fake_images_get))
 
