@@ -338,7 +338,6 @@ function configure_ceilometer {
         iniset $CEILOMETER_CONF coordination backend_url $CEILOMETER_COORDINATION_URL
         iniset $CEILOMETER_CONF notification workload_partitioning True
         iniset $CEILOMETER_CONF notification workers $API_WORKERS
-        iniset $CEILOMETER_CONF notification pipeline_processing_queues $API_WORKERS
     fi
 
     if [[ -n "$CEILOMETER_CACHE_BACKEND" ]]; then
@@ -443,7 +442,14 @@ function install_ceilometer {
     fi
 
     install_ceilometerclient
-    setup_develop $CEILOMETER_DIR
+
+    case $CEILOMETER_BACKEND in
+        mongodb) extra=mongo;;
+        gnocchi) extra=gnocchi;;
+        mysql) extra=mysql;;
+        postgresql) extra=postgresql;;
+    esac
+    setup_develop $CEILOMETER_DIR $extra
     sudo install -d -o $STACK_USER -m 755 $CEILOMETER_CONF_DIR
 }
 
